@@ -322,6 +322,7 @@ applet_fill_cb (PanelApplet *applet,
 			   "widget \"*.fast-user-switch-menubar\" style \"fast-user-switch-menubar-style\"\n"
 			   "widget \"*.fast-user-switch-applet\" style \"fast-user-switch-applet-style\"\n");
       gtk_window_set_default_icon_name ("stock_people");
+      g_set_application_name (_("Fast User Switch Applet"));
     }
 
   adata = g_new0 (FusaAppletData, 1);
@@ -778,12 +779,8 @@ applet_size_allocate_cb (GtkWidget     *widget,
   PanelAppletOrient orient;
   gint item_border;
   gint pixel_size;
-#if GTK_CHECK_VERSION (2,7,0)
   gdouble text_angle = 0.0;
   GtkPackDirection pack_direction = GTK_PACK_DIRECTION_LTR;
-#else
-  PangoEllipsizeMode ellipsize_mode;
-#endif
 
   adata = data;
   children = gtk_container_get_children (GTK_CONTAINER (adata->menubar));
@@ -801,42 +798,28 @@ applet_size_allocate_cb (GtkWidget     *widget,
     case PANEL_APPLET_ORIENT_DOWN:
       gtk_widget_set_size_request (top_item, -1, allocation->height);
       pixel_size = allocation->height - item_border;
-#if GTK_CHECK_VERSION (2,7,0)
       pack_direction = GTK_PACK_DIRECTION_RTL;
       text_angle = 0.0;
-#else
-      ellipsize_mode = PANGO_ELLIPSIZE_NONE;
-#endif /* HAVE_GTK28 */
       break;
     case PANEL_APPLET_ORIENT_LEFT:
       gtk_widget_set_size_request (top_item, allocation->width, -1);
       pixel_size = allocation->width - item_border;
-#if GTK_CHECK_VERSION (2,7,0)
       pack_direction = GTK_PACK_DIRECTION_TTB;
       text_angle = 270.0;
-#else
-      ellipsize_mode = PANGO_ELLIPSIZE_END;
-#endif /* HAVE_GTK28 */
       break;
     case PANEL_APPLET_ORIENT_RIGHT:
       gtk_widget_set_size_request (top_item, allocation->width, -1);
       pixel_size = allocation->width - item_border;
-#if GTK_CHECK_VERSION (2,7,0)
       pack_direction = GTK_PACK_DIRECTION_TTB;
       text_angle = 90.0;
-#else
-      ellipsize_mode = PANGO_ELLIPSIZE_END;
-#endif /* HAVE_GTK28 */
       break;
     default:
       g_assert_not_reached ();
       break;
     }
 
-#if GTK_CHECK_VERSION (2,7,0)
   gtk_menu_bar_set_pack_direction (GTK_MENU_BAR (adata->menubar),
                                    pack_direction);
-#endif /* HAVE_GTK28 */
 
   if (GTK_IS_IMAGE (adata->imglabel))
     {
@@ -845,13 +828,7 @@ applet_size_allocate_cb (GtkWidget     *widget,
     }
   else
     {
-#if GTK_CHECK_VERSION (2,7,0)
       gtk_label_set_angle (GTK_LABEL (adata->imglabel), text_angle);
-#else
-      gtk_label_set_ellipsize (GTK_LABEL (adata->imglabel),
-                               ellipsize_mode);
-#endif
-
     }
 }
 
@@ -1154,7 +1131,6 @@ about_cb (BonoboUIComponent *ui_container,
   license_i18n = g_strjoinv ("\n\n", license);
 
   gtk_show_about_dialog(NULL,
-      "name", _("Fast User Switch Applet"),
       "version", VERSION,
       "copyright", "Copyright \xc2\xa9 2004-2005 James M. Cape.\n"
                    "Copyright \xc2\xa9 2006 Thomas Thurman.",
@@ -1166,6 +1142,7 @@ about_cb (BonoboUIComponent *ui_container,
       "translator-credits", _("translator-credits"),
       "logo-icon-name", "stock_people",
       "website", "http://ignore-your.tv/fusa/",
+      "website-label", "Fast User Switch Applet Website",
       NULL
    );
 
